/*******************************************
Program                 : BT robot
Compiler                : WinAVR
Chip type               : ATtiny2313
System Clock            : 8 MHz
*******************************************/

#include <avr/io.h>
#include <util/delay.h>

unsigned char count = 0;
unsigned char usart_data = 's';

void USART_Init( unsigned int baud )
{
    // Set baud rate
    UBRRH = (unsigned char)(baud>>8);
    UBRRL = (unsigned char)baud;

    // Enable receiver and transmitter
    UCSRB = (1<<RXEN)|(1<<TXEN);

    // Set frame format: 8 data, 1 stop bit
    UCSRC = (1<<UCSZ1)|(1<<UCSZ0);
}

void Ports_Init( void )
{
    // Port D initialization
    DDRD = 0b00111100;
    PORTD = 0b00000000;

    // Port B initialization
    DDRB = 0b00000000;
    PORTB = 0b00000000;

    // Port A initialization
    DDRA = 0b00000000;
    PORTA = 0b00000000;
}

int main( void )
{
    // System Clock Prescaler initialization

    // Clock Prescale Register
    // Bits: CLKPCE - - - CLKPS3 CLKPS2 CLKPS1 CLKPS0
    CLKPR = 0b10000000;
    CLKPR = 0b00000000; // Clock division factor 1

    // Input/Output Ports initialization
    Ports_Init();

    // USART initialization
    USART_Init(51); // Baud Rate 9600 bps


    while(1)
    {
        //  
        if ( UCSRA & (1<<RXC) )
        {
            usart_data = UDR;
            count = 0;
        }

        // 
        if ( usart_data == 'f' )
        {
            PORTD |= 0b00000100; //  1  PD2
            _delay_us(2000); // 
            PORTD &= 0b11111011; //  0  PD2

            PORTD |= 0b00001000; //  1  PD3
            _delay_us(2000); // 
            PORTD &= 0b11110111; //  0  PD3

            PORTD |= 0b00010000; //  1  PD4
            _delay_us(1000); // 
            PORTD &= 0b11101111; //  0  PD4

            PORTD |= 0b00100000; //  1  PD5
            _delay_us(1000); // 
            PORTD &= 0b11011111; //  0  PD5

            _delay_ms(13); // 
        }

        // 
        if ( usart_data == 'b' )
        {
            PORTD |= 0b00000100; //  1  PD2
            _delay_us(1000); // 
            PORTD &= 0b11111011; //  0  PD2

            PORTD |= 0b00001000; //  1  PD3
            _delay_us(1000); // 
            PORTD &= 0b11110111; //  0  PD3

            PORTD |= 0b00010000; //  1  PD4
            _delay_us(2000); // 
            PORTD &= 0b11101111; //  0  PD4

            PORTD |= 0b00100000; //  1  PD5
            _delay_us(2000); // 
            PORTD &= 0b11011111; //  0  PD5

            _delay_ms(13); // 
        }

        // 
        if ( usart_data == 'l' )
        {
            PORTD |= 0b00000100; //  1  PD2
            _delay_us(1000); // 
            PORTD &= 0b11111011; //  0  PD2

            PORTD |= 0b00001000; //  1  PD3
            _delay_us(1000); // 
            PORTD &= 0b11110111; //  0  PD3

            PORTD |= 0b00010000; //  1  PD4
            _delay_us(1000); // 
            PORTD &= 0b11101111; //  0  PD4

            PORTD |= 0b00100000; //  1  PD5
            _delay_us(1000); // 
            PORTD &= 0b11011111; //  0  PD5

            _delay_ms(15); // 
        }

        // 
        if ( usart_data == 'r' )
        {
            PORTD |= 0b00000100; //  1  PD2
            _delay_us(2000); // 
            PORTD &= 0b11111011; //  0  PD2

            PORTD |= 0b00001000; //  1  PD3
            _delay_us(2000); // 
            PORTD &= 0b11110111; //  0  PD3

            PORTD |= 0b00010000; //  1  PD4
            _delay_us(2000); // 
            PORTD &= 0b11101111; //  0  PD4

            PORTD |= 0b00100000; //  1  PD5
            _delay_us(2000); // 
            PORTD &= 0b11011111; //  0  PD5

            _delay_ms(11); //
        }

        //    5   , 
        if ( count == 250 )
        {
            usart_data = 's';
        }
        else
        {
            count += 1;
        }
    }

    return 0;
}
